@@ -46,17 +46,17 @@ static void CONCAT(_nsw_end,FUNCOBJENT)(int ptr)
 	    
 #ifdef ENABLE_NIS
       case NSWO_NISPLUS:
-	CONCAT(nis_end,FUNCOBJENT)(NULL);
+	CONCAT(nis_end,FUNCOBJENT)();
 	break;
 #endif
 #ifdef ENABLE_YP
       case NSWO_NIS:
-	CONCAT(yp_end,FUNCOBJENT)(NULL);
+	CONCAT(yp_end,FUNCOBJENT)();
 	break;
 #endif
 #ifdef ENABLE_DNS
       case NSWO_DNS:
-	CONCAT(dns_end,FUNCOBJENT)(NULL);
+	CONCAT(dns_end,FUNCOBJENT)();
 	break;
 #endif
     }
@@ -65,17 +65,21 @@ static void CONCAT(_nsw_end,FUNCOBJENT)(int ptr)
 
 void CONCAT(CONCAT(NSWPREFIX,end),FUNCOBJENT)(void)
 {
+    static int CONCAT(recur_,FUNCOBJENT) = 0;
     setflag = 0;
     
     
-    if (nswp == NULL)
+    if (nswp == NULL || CONCAT(recur_,FUNCOBJENT) == 1)
 	CONCAT(ENDPREFIX,FUNCOBJENT)();
     else
     {
+	CONCAT(recur_,FUNCOBJENT) = 1;
 	if (setptr == nswp->orderc)
 	    setptr--;
 	
 	CONCAT(_nsw_end,FUNCOBJENT)(setptr);
+	
+	CONCAT(recur_,FUNCOBJENT) = 0;
     }
 
     setptr = 0;
