@@ -27,7 +27,7 @@
 
 #include <stdio.h>
 #include <errno.h>
-#include "dns_networks.h"
+#include <netdb.h>
 
 
 void dns_setnetent(int stayopen)
@@ -54,7 +54,7 @@ struct netent *dns_getnetbyname(const char *name)
 }
 
 
-struct netent *dns_getnetbyaddr(long net, int type)
+struct netent *dns_getnetbyaddr(unsigned long net, int type)
 {
     errno = ECONNREFUSED;
     return NULL;
