@@ -24,12 +24,40 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include "pwd.h"
 #include "shadow.h"
 #include "misc.h"
 #include "xalloc.h"
 
 
 static FILE *sfp = NULL;
+static FILE *pfp = NULL;
+
+
+static struct spwd *pw_fgetspent(FILE *fp)
+{
+    static struct spwd spb;
+    static char *pwbuf = NULL;
+    static int pwlen = 0;
+    struct passwd *pwp;
+
+    
+    pwp = _fgetpwent(fp, &pwbuf, &pwlen);
+    if (pwp == NULL)
+	return NULL;
+
+    spb.sp_namp = pwp->pw_name;
+    spb.sp_pwdp = pwp->pw_passwd;
+    spb.sp_lstchg = -1;
+    spb.sp_min = -1;
+    spb.sp_max = -1;
+    spb.sp_warn = -1;
+    spb.sp_inact = -1;
+    spb.sp_expire = -1;
+    spb.sp_flag = (unsigned long) -1;
+
+    return &spb;
+}
 
 
 struct spwd *sgetspent(const char *buf)
@@ -44,18 +72,6 @@ struct spwd *sgetspent(const char *buf)
 
     strcpy(sbuf, buf);
 
-    if (spb.sp_namp)
-    {
-	free(spb.sp_namp);
-	spb.sp_namp = NULL;
-    }
-    
-    if (spb.sp_pwdp)
-    {
-	free(spb.sp_pwdp);
-	spb.sp_pwdp = NULL;
-    }
-
     spb.sp_lstchg = spb.sp_min = spb.sp_max = spb.sp_warn = -1;
     spb.sp_inact = spb.sp_expire = -1;
     spb.sp_flag = -1;
@@ -66,9 +82,7 @@ struct spwd *sgetspent(const char *buf)
 
     if (*cp)
 	*cp++ = '\0';
-    spb.sp_namp = strdup(sp);
-    if (spb.sp_namp == NULL)
-	return NULL;
+    spb.sp_namp = sp;
     
     sp = cp;
     cp = strchr(sp, ':');
@@ -77,9 +91,7 @@ struct spwd *sgetspent(const char *buf)
 
     if (*cp)
 	*cp++ = '\0';
-    spb.sp_pwdp = strdup(sp);
-    if (spb.sp_pwdp == NULL)
-	return NULL;
+    spb.sp_pwdp = sp;
 
     
     sp = cp;
@@ -193,7 +205,24 @@ void _setspent(void)
     if (sfp)
 	rewind(sfp);
     else
+    {
 	sfp = fopen(_PATH_SHADOW, "r");
+	if (sfp == NULL)
+	{
+fprintf(stderr, "Getting shadow info from passwd file...\n");	    
+	    if (pfp)
+		rewind(pfp);
+	    else
+		pfp = fopen(_PATH_PASSWD, "r");
+	}
+	else
+	    if (pfp)
+	    {
+fprintf(stderr, "Closing passwd file since not needed anymore.\n");
+		fclose(pfp);
+		pfp = NULL;
+	    }
+    }
 }
 
 
@@ -201,17 +230,25 @@ void _endspent(void)
 {
     if (sfp)
 	fclose(sfp);
+
+    if (pfp)
+	fclose(pfp);
+    
     sfp = NULL;
+    pfp = NULL;
 }
 
 
 struct spwd *_getspent(void)
 {
-    if (sfp == NULL)
+    if (sfp == NULL && pfp == NULL)
 	_setspent();
     
     if (sfp == NULL)
-	return NULL;
+    {
+fprintf(stderr, "Getting shadow entry from passwd file\n");
+	return pw_fgetspent(pfp);
+    }
 
     return fgetspent(sfp);
 }
