@@ -27,7 +27,7 @@
 
 #include <stdio.h>
 #include <errno.h>
-#include "nis_ethers.h"
+#include <ethers.h>
 
 
 void nis_setethent(void)
