@@ -30,7 +30,7 @@
 
 #include <stdio.h>
 #include <errno.h>
-#include "nis_group.h"
+#include <grp.h>
 
 
 void nis_setgrent(void)
@@ -50,7 +50,7 @@ struct group *nis_getgrent(void)
 }
 
 
-struct group *nis_getgrgid(gid_t gid)
+struct group *nis_getgrgid(int gid)
 {
     errno = ECONNREFUSED;
     return NULL;
