@@ -30,7 +30,7 @@
 
 #include <stdio.h>
 #include <errno.h>
-#include "nis_gshadow.h"
+#include <gshadow.h>
 
 
 void nis_setsgent(void)
