@@ -27,7 +27,7 @@
 
 #include <stdio.h>
 #include <errno.h>
-#include "nis_networks.h"
+#include <netdb/networks.h>
 
 
 void nis_setnetent(int stayopen)
@@ -54,7 +54,7 @@ struct netent *nis_getnetbyname(const char *name)
 }
 
 
-struct netent *nis_getnetbyaddr(long net, int type)
+struct netent *nis_getnetbyaddr(unsigned long net, int type)
 {
     errno = ECONNREFUSED;
     return NULL;
