@@ -27,7 +27,7 @@
 
 #include <stdio.h>
 #include <errno.h>
-#include "nis_protocols.h"
+#include <netdb/protocols.h>
 
 
 void nis_setprotoent(int stayopen)
