@@ -27,7 +27,7 @@
 
 #include <stdio.h>
 #include <errno.h>
-#include "nis_rpc.h"
+#include <netdb/rpc.h>
 
 
 void nis_setrpcent(int stayopen)
