@@ -36,9 +36,9 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
+#include <netdb/hosts.h>
 #include "xalloc.h"
 #include "yp_misc.h"
-#include "yp_hosts.h"
 #include "rpcsvc/ypclnt.h"
 
 static int rewind_flag = 1;
