@@ -33,9 +33,8 @@
 #include <string.h>
 #include <stdlib.h>
 #include <ctype.h>
-
+#include <shadow.h>
 #include "yp_misc.h"
-#include "yp_shadow.h"
 #include "rpcsvc/ypclnt.h"
 
 #include "xalloc.h"
