@@ -24,7 +24,7 @@
 */
 
 #include <stdio.h>
-#include "nis_passwd.h"
+#include <pwd.h>
 
 extern void print_passwd(struct passwd *);
 
